#
# spec file for package wayprompt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wayprompt
Version:        0.1.2
Release:        2.3
Summary:        Multi-purpose prompt tool for Wayland
License:        GPL-3.0-only
URL:            https://git.sr.ht/~leon_plickat/wayprompt/
Source0:        https://git.sr.ht/~leon_plickat/wayprompt/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  fdupes
BuildRequires:  scdoc
BuildRequires:  zig = 0.13.0
BuildRequires:  zig-rpm-macros = 0.13.0
BuildRequires:  zstd
BuildRequires:  pkgconfig(fcft)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.20.0
BuildRequires:  pkgconfig(xkbcommon)

Provides:       pinentry-wayprompt = %{version}

%description
Multi-purpose prompt tool for Wayland

To use as a pinentry replacement, run as 'pinentry-wayprompt'.
To use as a himitsu prompter, run as 'hiprompt-wayprompt'. (TODO)
To use as a generic prompter for scripts, run as 'wayprompt-cli'.

%prep
%autosetup -a1 -p1 -n %{name}-v%{version}

%build
%zig_build -Dpie --global-cache-dir vendor/

%install
%zig_install -Dpie --global-cache-dir vendor/
%fdupes %{buildroot}

%files
%{_bindir}/%{name}
%{_bindir}/pinentry-%{name}
%{_bindir}/%{name}-ssh-askpass
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-ssh-askpass.1%{?ext_man}
%{_mandir}/man1/pinentry-%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.5%{?ext_man}
%doc README.md
%license LICENSE

%changelog
* Thu Sep 26 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Remove comment from specfile. It is not true as of writing this.
* Wed Sep 25 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 0.1.2
  * changes are brought over since 0.1.0+14 as a new release
    as well as the fix-zig-spoon-hash.patch
- Remove ./fix-zig-spoon-hash.patch
* Tue Jul 30 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Added new prompt to support ssh askpass
* Tue Jul 30 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 0.1.0+14:
  * handle wl_touch.cancel events
  * implement touch support
  * do not vendor zig-ini
  * replace FlagIt with std.process.ArgIteratorPosix
  * options: add strip and llvm options
  * gitignore: add .zig-cache to ignore
  * build: cleanup migration to Zig 0.13.0
  * build: update to Zig 0.13.0
  * build: update to Zig 0.12.0
  * doc/wayprompt.5: Fix typo
  * build: install wayprompt-ssh-askpass.1
  * README: add wayprompt-ssh-askpass
  * add wayprompt-ssh-askpass
  * wayprompt-cli: return value based on user-action
- Add fix-zig-spoon-hash.patch
* Wed Mar 20 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Updated listed file in specfile:
  * README -> README.md
* Sun Mar 17 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.1.0:
  * add option to build PIE executables
  * correctly declare log functions and fix potential formatstring injection
  * allocate correct capacity in hotspot list
  * move circle mask to dedicated struct
  * update README
  * fix: correctly handle closed stdin and multiple commands in one read()
  * support cursor-shape-v1
  * separate colour configuration for all button borders and texts
  * make default colour definitions a bit cleaner
  * support transparent colours
  * fix endless loop on exit
  * c i r c l e
  * port to zig 0.11.0
* Tue Dec  5 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1696931954.a36891e:
  * make fonts configurable
  * Add test target to build.zig
  * add tests
  * doc: typo
  * fix config file parsing
  * improve config file parsing
  * clear secret buffer on C-w and C-backspace
  * fix crash when pressing backspace while not prompting for secret
  * backends: use globals
  * doc: Fix typos
- Remove 0000-add-position-independent-executable-and-strip-build-options.patch
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Wed Mar 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- This also provides the following:
  * pinentry-wayprompt
  * hiprompt-wayprompt
* Sun Jan 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-add-position-independent-executable-and-strip-build-options.patch
* Sat Jan 21 2023 socvirnyl.estela@gmail.com
- Update to version 1673601885.3d73732:
  * fix crash on bad config section
  * Set correct syslog priority
  * Revert "potentially fix font-spacing"
  * allow JSON output for cli mode
  * fix --help text
  * potentially fix font-spacing
  * update to zig0.10.0
  * Default to CLI interface
  * bind version 3 of layer shell
  * pinentry: fix error.BrokenPipe on exit
  * pinentry: log to syslog
  * Improve security of pin storage
* Tue Nov  8 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for wayprompt 1666113891.ff0004a (No tagged version yet).
